@@ -1,9 +1,9 @@
 use strict;
-use warnings;
+BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
 package Test::Reporter::Transport::File;
 use base 'Test::Reporter::Transport';
 use vars qw/$VERSION/;
-$VERSION = '1.5203';
+$VERSION = '1.54';
 $VERSION = eval $VERSION;
 
 sub new {
